package com.ruoyi.ss.store.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.ss.store.domain.StoreQuery;
import com.ruoyi.ss.store.domain.StoreVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ss.store.mapper.StoreMapper;
import com.ruoyi.ss.store.domain.Store;
import com.ruoyi.ss.store.service.IStoreService;

/**
 * 商户列表Service业务层处理
 *
 * @author ruoyi
 * @date 2024-04-26
 */
@Service
public class StoreServiceImpl implements IStoreService
{
    @Autowired
    private StoreMapper storeMapper;

    /**
     * 查询商户列表
     *
     * @param storeId 商户列表主键
     * @return 商户列表
     */
    @Override
    public StoreVO selectStoreByStoreId(Long storeId)
    {
        return storeMapper.selectStoreByStoreId(storeId);
    }

    /**
     * 查询商户列表列表
     *
     * @param store 商户列表
     * @return 商户列表
     */
    @Override
    public List<StoreVO> selectStoreList(StoreQuery store)
    {
        return storeMapper.selectStoreList(store);
    }

    /**
     * 新增商户列表
     *
     * @param store 商户列表
     * @return 结果
     */
    @Override
    public int insertStore(Store store)
    {
        store.setCreateTime(DateUtils.getNowDate());
        return storeMapper.insertStore(store);
    }

    /**
     * 修改商户列表
     *
     * @param store 商户列表
     * @return 结果
     */
    @Override
    public int updateStore(Store store)
    {
        store.setUpdateTime(DateUtils.getNowDate());
        return storeMapper.updateStore(store);
    }

    /**
     * 批量删除商户列表
     *
     * @param storeIds 需要删除的商户列表主键
     * @return 结果
     */
    @Override
    public int deleteStoreByStoreIds(Long[] storeIds)
    {
        return storeMapper.deleteStoreByStoreIds(storeIds);
    }

    /**
     * 删除商户列表信息
     *
     * @param storeId 商户列表主键
     * @return 结果
     */
    @Override
    public int deleteStoreByStoreId(Long storeId)
    {
        return storeMapper.deleteStoreByStoreId(storeId);
    }
}
