package com.ruoyi.web.controller.ss;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.ss.store.domain.StoreQuery;
import com.ruoyi.ss.store.domain.StoreVO;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ss.store.domain.Store;
import com.ruoyi.ss.store.service.IStoreService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 商户列表Controller
 *
 * @author ruoyi
 * @date 2024-04-26
 */
@RestController
@RequestMapping("/ss/store")
public class StoreController extends BaseController
{
    @Autowired
    private IStoreService storeService;

    /**
     * 查询商户列表列表
     */
    @PreAuthorize("@ss.hasPermi('ss:store:list')")
    @GetMapping("/list")
    public TableDataInfo list(StoreQuery store)
    {
        startPage();
        List<StoreVO> list = storeService.selectStoreList(store);
        return getDataTable(list);
    }

    /**
     * 导出商户列表列表
     */
    @PreAuthorize("@ss.hasPermi('ss:store:export')")
    @Log(title = "商户列表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, StoreQuery store)
    {
        List<StoreVO> list = storeService.selectStoreList(store);
        ExcelUtil<StoreVO> util = new ExcelUtil<StoreVO>(StoreVO.class);
        util.exportExcel(response, list, "商户列表数据");
    }

    /**
     * 获取商户列表详细信息
     */
    @PreAuthorize("@ss.hasPermi('ss:store:query')")
    @GetMapping(value = "/{storeId}")
    public AjaxResult getInfo(@PathVariable("storeId") Long storeId)
    {
        return success(storeService.selectStoreByStoreId(storeId));
    }

    /**
     * 新增商户列表
     */
    @PreAuthorize("@ss.hasPermi('ss:store:add')")
    @Log(title = "商户列表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Store store)
    {
        return toAjax(storeService.insertStore(store));
    }

    /**
     * 修改商户列表
     */
    @PreAuthorize("@ss.hasPermi('ss:store:edit')")
    @Log(title = "商户列表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Store store)
    {
        return toAjax(storeService.updateStore(store));
    }

    /**
     * 删除商户列表
     */
    @PreAuthorize("@ss.hasPermi('ss:store:remove')")
    @Log(title = "商户列表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{storeIds}")
    public AjaxResult remove(@PathVariable Long[] storeIds)
    {
        return toAjax(storeService.deleteStoreByStoreIds(storeIds));
    }
}
